@@ -1,7 +1,10 @@
 /*
  *      lxinput.c
  *
- *      Copyright 2009 PCMan <pcman.tw@gmail.com>
+ *      Copyright 2009-2011 PCMan <pcman.tw@gmail.com>
+ *      Copyright 2009 martyj19 <martyj19@comcast.net>
+ *      Copyright 2011-2013 Julien Lavergne <julien.lavergne@gmail.com>
+ *      Copyright 2014 Andriy Grytsenko <andrej@rep.kiev.ua>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -294,9 +297,9 @@ int main(int argc, char** argv)
     g_signal_connect(mouse_left_handed, "toggled", G_CALLBACK(on_left_handed_toggle), NULL);
 
     set_range_stops(kb_delay, 10);
-    g_signal_connect(kb_delay, "value-changed", G_CALLBACK(on_kb_range_changed), &kb_delay);
+    g_signal_connect(kb_delay, "value-changed", G_CALLBACK(on_kb_range_changed), &delay);
     set_range_stops(kb_interval, 10);
-    g_signal_connect(kb_interval, "value-changed", G_CALLBACK(on_kb_range_changed), &kb_interval);
+    g_signal_connect(kb_interval, "value-changed", G_CALLBACK(on_kb_range_changed), &interval);
     g_signal_connect(kb_beep, "toggled", G_CALLBACK(on_kb_beep_toggle), NULL);
     g_signal_connect(kb_layout, "clicked", G_CALLBACK(on_kb_layout_clicked), NULL);
 
@@ -346,13 +349,14 @@ int main(int argc, char** argv)
                                   "Name=%s\n"
                                   "Comment=%s\n"
                                   "NoDisplay=true\n"
-                                  "Exec=sh -c 'xset m %d/10 %d r rate %d %d b %s'\n"
+                                  "Exec=sh -c 'xset m %d/10 %d r rate %d %d b %s%s'\n"
                                   "NotShowIn=GNOME;KDE;XFCE;\n",
                                   _("LXInput autostart"),
                                   _("Setup keyboard and mouse using settings done in LXInput"),
                                   /* FIXME: how to setup left-handed mouse? */
                                   accel, threshold, delay, interval,
-                                  beep ? "on" : "off");
+                                  beep ? "on" : "off",
+                                  left_handed ? ";xmodmap -e \"pointer = 3 2 1\"" : "");
             g_file_set_contents(user_config_file, str, -1, NULL);
             g_free(str);
         }
